# Book Maker

Tool to build PDF books from markdown files and draw.io diagrams.

The attached fonts can be utilized without purchasing any license for non-commercial projects.
However, for any commercial purpose, you will have to purchase the license in order to use some
font legally.
